@@ -2,7 +2,6 @@ import argparse
 import logging
 import os
 from pathlib import Path
-from shutil import copyfile
 import subprocess
 import sys
 
@@ -13,7 +12,7 @@ except ImportError:
 
 
 LOGGING_LEVELS = [logging.getLevelName(level).lower() for level in range(0, 51, 10)]
-VERSION = "2020.10.14"  # Avoid importing optimade-client package
+VERSION = "2020.10.29"  # Avoid importing optimade-client package
 
 
 def main(args: list = None):
@@ -59,22 +58,21 @@ def main(args: list = None):
             "(and ASE for a larger download format selection)."
         )
 
-    # Rename jupyter_config.json to voila.json and copy it Jupyter's config dir
-    jupyter_config_dir = subprocess.getoutput("jupyter --config-dir")
-    Path(jupyter_config_dir).mkdir(parents=True, exist_ok=True)
-    copyfile(
-        Path(__file__).parent.parent.parent.joinpath("jupyter_config.json").resolve(),
-        f"{jupyter_config_dir}/voila.json",
+    notebook = str(
+        Path(__file__).parent.joinpath("static/OPTIMADE-Client.ipynb").resolve()
     )
+    config_path = str(Path(__file__).parent.joinpath("static").resolve())
 
     # "Trust" notebook
-    subprocess.run(
-        ["jupyter", "trust", "OPTIMADE Client.ipynb"],
-        cwd=Path(__file__).parent.parent.parent.resolve(),
-        check=False,
-    )
+    subprocess.run(["jupyter", "trust", notebook], check=False)
 
-    argv = ["OPTIMADE Client.ipynb"]
+    argv = [notebook]
+
+    if sys.version_info.minor <= 6:
+        # Python 3.6 and below (officially only supports Python 3.6+)
+        argv.append(f'--Voila.config_file_paths=["{config_path}"]')
+    else:
+        argv.append(f"--Voila.config_file_paths={config_path}")
 
     if debug:
         if log_level not in ("debug", "info"):
